<!--
Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements. See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
-->
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd class="cell"">
<%@ page language="java" contentType="text/html; charset=ISO-8859-1" pageEncoding="ISO-8859-1" %>
<html>
<head>
    <title>A Stateless Session Sample - Calculator</title>
    <meta content="text/html; CHARSET=iso-8859-1" http-equiv="Content-Type"/>
    <style type="text/css">
        .header {
            background-color: aqua;
            text-align: center
        }

        .cell {
            text-align: center
        }
    </style>
</head>

<body>
<font face="Verdana, Helvetica, Arial">
    <h2>A Stateless Session Sample</h2>

    <h3>Calculator</h3>
    <font style="font-size:12px">
        <p>
            This sample shows an EJB 3.0 Stateless session bean.
            <%
                String result = String.valueOf(request.getAttribute("result"));
                result = ("null".equals(result)) ? "0" : result;
                request.setAttribute("result", null);
                request.removeAttribute("result");
            %>

        </p>

        <form action="calculator" method="get">
            <table border="3" id="mainTable" cellpadding="0">
                <thead id="mainTableHead">
                    <tr>
                        <td class="header">First Number</td>
                        <td class="header">Second Number</td>
                        <td class="header">Operation</td>
                        <td class="header">Result</td>
                    </tr>
                </thead>
                <tr>
                    <td class="cell">
                        <input type="text" name="firstNumber" value="0"/>
                    </td>
                    <td class="cell">
                        <input type="text" name="secondNumber" value="0"/>
                    </td>
                    <td class="cell">
                        <input type="submit" name="operation" value="add"/>
                        <br/>
                        <input type="submit" name="operation" value="multiply"/>
                    </td>
                    <td class="cell"><%=result%>
                    </td>
                </tr>
            </table>
        </form>
        <p>
            This sample demonstrates the following new features from EJB 3.0
        <ol>
            <li>Elimination of the requirement for EJB component interfaces for session beans. The required
                business interface for a session bean can be a plain Java interface rather than an EJBObject,
                EJBLocalObject, or java.rmi.Remote interface.
            <li>Elimination of the requirement for home interfaces for session beans.
            <li>Encapsulation of environmental dependencies and JNDI access through the use of annotations,
                dependency injection mechanisms, and simple lookup mechanisms.
            <li>Introduction of Java metadata annotations to be used as an alternative to deployment descriptors.
        </ol>
        <p>
    </font>

    <h3>A POJO as a business interface</h3>
    <font style="font-size:12px">
        Notice that the stateless session bean <a href="./xref/org/apache/geronimo/samples/slsb/calculator/Calculator.html" target="source_window"><code>Calculator.java</code></a> implements
        just a simple java interface and not an EJB component interface like EJBObject, EJBLocalObject or java.rmi.Remote.
    </font>

    <h3>Dependency Injection</h3>
    <font style="font-size:12px">
        Notice that the servlet <a href="./xref/org/apache/geronimo/samples/calculator/CalculatorServlet.html" target="source_window"><code>CalculatorServlet.java</code></a>
        declares an instance variable with an @EJB annotation. The variable is that of a session bean and it's type is the same as that of it's business interface.
        In earlier versions, the servlet would have done a JNDI lookup of the bean's home interface in the component's environment.
        It then would have had to create the instance using the create method of the home interface.
        However in Java EE 5.0, the servlet can just declare its dependency on the bean by just annotating the instance variable with the @EJB annotation.
        When the servlet instance is created during runtime, the container automatically initializes these annotated variables with an instance of an object that implements the business interface.
        This initialization occurs before any business methods are invoked on the bean instance and after the time the beans EJBContext is set.
    </font>

    <h3>No deployment descriptor</h3>
    <font style="font-size:12px">
        Notice the absence of the traditional deployment descriptor, <code>ejb-jar.xml</code>. The bean declarations that used to be done there are now done by the
        annotations in the code.
    </font>

</font>
</body>
</html>
